@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 
-package App::Cmd::Command::commands;
-$App::Cmd::Command::commands::VERSION = '0.333';
+package App::Cmd::Command::commands 0.336;
+
 use App::Cmd::Command;
 BEGIN { our @ISA = 'App::Cmd::Command' };
 
@@ -104,13 +104,23 @@ App::Cmd::Command::commands - list the application's commands
 
 =head1 VERSION
 
-version 0.333
+version 0.336
 
 =head1 DESCRIPTION
 
 This command will list all of the application commands available and their
 abstracts.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 METHODS
 
 =head2 execute
@@ -137,11 +147,11 @@ your application base clase.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2023 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
