@@ -1,11 +1,15 @@
-use strict;
+# The "experimental" below is not actually scary.  The feature went on to be
+# de-experimental-ized with no changes and is now on by default in perl v5.24
+# and later. -- rjbs, 2021-03-14
+use 5.020;
 use warnings;
+use experimental qw(postderef postderef_qq);
+
+package App::Cmd::Subdispatch 0.336;
 
-package App::Cmd::Subdispatch;
-$App::Cmd::Subdispatch::VERSION = '0.332';
 use App::Cmd;
 use App::Cmd::Command;
-BEGIN { our @ISA = qw(App::Cmd::Command App::Cmd) } 
+BEGIN { our @ISA = qw(App::Cmd::Command App::Cmd) }
 
 # ABSTRACT: an App::Cmd::Command that is also an App::Cmd
 
@@ -110,7 +114,17 @@ App::Cmd::Subdispatch - an App::Cmd::Command that is also an App::Cmd
 
 =head1 VERSION
 
-version 0.332
+version 0.336
+
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 METHODS
 
@@ -144,11 +158,11 @@ C<< $cmd->app >>.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2023 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
